@@ -3,9 +3,11 @@ Main interface for dynamodb service type definitions.
 
 Usage::
 
-    from mypy_boto3.dynamodb.type_defs import ArchivalSummaryTypeDef
+    ```python
+    from mypy_boto3_dynamodb.type_defs import ArchivalSummaryTypeDef
 
     data: ArchivalSummaryTypeDef = {...}
+    ```
 """
 from datetime import datetime
 from decimal import Decimal
